## Typing stubs for openpyxl

This is a [type stub package](https://typing.python.org/en/latest/tutorials/external_libraries.html)
for the [`openpyxl`](https://foss.heptapod.net/openpyxl/openpyxl) package. It can be used by type checkers
to check code that uses `openpyxl`. This version of
`types-openpyxl` aims to provide accurate annotations for
`openpyxl==3.1.5`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/openpyxl`](https://github.com/python/typeshed/tree/main/stubs/openpyxl)
directory.

This package was tested with the following type checkers:
* [mypy](https://github.com/python/mypy/) 1.18.1
* [pyright](https://github.com/microsoft/pyright) 1.1.405

It was generated from typeshed commit
[`4b0623f4fb2c4e5a04a0244e1592b1481a26e47e`](https://github.com/python/typeshed/commit/4b0623f4fb2c4e5a04a0244e1592b1481a26e47e).